@@ -120,7 +120,7 @@ run_job = '''
   mutation runJob(
     $id: ID!
     $status: JobStatus!
-    $queueName: String!, 
+    $queueName: String!,
     $lastRunAt: DateTime!
   ) {
     updateJob(
@@ -163,6 +163,18 @@ run_event_job = '''
       id
       jobStatus
       progress
+      userId
+      queue {
+        id
+        name
+      }
+      worker {
+        id
+        code
+      }
+      input
+      context
+      output
     }
   }
   queue: updateQueue(
