@@ -433,26 +433,36 @@ class ValiotWorker():
             disabled,
             not_listened
         ) = self.groupQueuesByListenStatus(self.currentQueues)
-        self.log(LogLevel.SUCCESS, 'LISTENED Queues:')
+
+        # this avoids mis-labeling logs when using JSON logging
+        SUCCESS_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.SUCCESS
+        WARNING_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.WARNING
+        ERROR_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.ERROR
+
+        self.log(SUCCESS_STYLE, 'LISTENED Queues:')
         for queue_name in listened:
-            self.log(LogLevel.SUCCESS, f"\t{queue_name}")
+            self.log(SUCCESS_STYLE, f"\t{queue_name}")
         if not listened:
-            self.log(LogLevel.SUCCESS,
+            self.log(SUCCESS_STYLE,
                      f'{self.worker_code} not listening to any Queue')
-        self.log(LogLevel.WARNING, 'DISABLED Queues:')
+        self.log(WARNING_STYLE, 'DISABLED Queues:')
         for queue_name in disabled:
-            self.log(LogLevel.WARNING, f"\t{queue_name}")
+            self.log(WARNING_STYLE, f"\t{queue_name}")
         if not disabled:
-            self.log(LogLevel.WARNING, f'\tNo queues disabled')
-        self.log(LogLevel.ERROR, 'NOT LISTENED Queues:')
+            self.log(WARNING_STYLE, f'\tNo queues disabled')
+        self.log(ERROR_STYLE, 'NOT LISTENED Queues:')
         for queue_name in not_listened:
-            self.log(LogLevel.ERROR, f"\t{queue_name}")
+            self.log(ERROR_STYLE, f"\t{queue_name}")
         if not not_listened:
             self.log(LogLevel.INFO, f'\tAll queues listened')
 
     def reportListenedQueuesDiff(self):
         """This function makes a report with logs of the difference of all queues.
         """
+        # this avoids mis-labeling logs when using JSON logging
+        SUCCESS_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.SUCCESS
+        WARNING_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.WARNING
+        ERROR_STYLE = LogLevel.INFO if self.loggingStyle == LogStyle.JSON else LogLevel.ERROR
         (
             listened,
             disabled,
@@ -467,17 +477,17 @@ class ValiotWorker():
         disabled_diff = set(disabled) - set(prev_disabled)
         not_listened_diff = set(not_listened) - set(prev_not_listened)
         if listened_diff:
-            self.log(LogLevel.SUCCESS, f'NEW LISTENED QUEUES:')
+            self.log(SUCCESS_STYLE, f'NEW LISTENED QUEUES:')
             for queue_name in listened_diff:
-                self.log(LogLevel.SUCCESS, f'\t{queue_name}')
+                self.log(SUCCESS_STYLE, f'\t{queue_name}')
         if disabled_diff:
-            self.log(LogLevel.WARNING, f'NEW DISABLED QUEUES:')
+            self.log(WARNING_STYLE, f'NEW DISABLED QUEUES:')
             for queue_name in disabled_diff:
-                self.log(LogLevel.WARNING, f'\t{queue_name}')
+                self.log(WARNING_STYLE, f'\t{queue_name}')
         if not_listened_diff:
-            self.log(LogLevel.ERROR, f'NEW NOT LISTENED QUEUES:')
+            self.log(ERROR_STYLE, f'NEW NOT LISTENED QUEUES:')
             for queue_name in not_listened_diff:
-                self.log(LogLevel.ERROR, f'\t{queue_name}')
+                self.log(ERROR_STYLE, f'\t{queue_name}')
 
     def reportQueueChanges(self):
         """This function makes a report with all queues changes.
@@ -538,9 +548,10 @@ class ValiotWorker():
             'active': False,
             'endAt': getUtcDate(datetime.now()).strftime("%Y-%m-%dT%H:%M:%SZ")
         }
-        current_lock, errors = self.gql.query(queries.get_queueLock, variables={"lockId": lock['id']})
+        current_lock, errors = self.gql.query(
+            queries.get_queueLock, variables={"lockId": lock['id']})
         if not current_lock:
-            return True # lock already unlocked
+            return True  # lock already unlocked
         data, errors = self.gql.mutate(mutations.update_lock, variables)
         lock = __.get(data, 'result')
         queue_index = __.arrays.find_index(
@@ -557,6 +568,9 @@ class ValiotWorker():
         Raises:
             Exception: Missing status of the job.
         """
+        # Obtiene logger para poder loggear en nombre del job (si no, se loggea en nombre del worker y se pierde en DataDog)
+        log_from_job = self.getProcessLoggerFunction(
+            queue=job['queue'], job=job)
         # obtiene lock (if needed):
         lock = None
         if job["queue"]["lockRequired"]:
@@ -565,13 +579,13 @@ class ValiotWorker():
         fn_name, job_dict = self.getJobData(job)
         # ! Validates existence of requested job for this worker:
         if not job_dict:
-            self.log(
+            log_from_job(
                 LogLevel.ERROR,
                 f"{fn_name} job not found (it might exist in another branch / parallel universe), skipping..."
             )
             # TODO: Here we can update the job to aborted or something
             return
-        self.log(LogLevel.INFO, f"running {fn_name}")
+        log_from_job(LogLevel.INFO, f"running {fn_name}")
         job_fn = job_dict['function']
         # Obtiene inputs
         if job['input']:
@@ -589,7 +603,14 @@ class ValiotWorker():
                     'output': f'Job input error: {str(e)}'
                 }
                 uploaders.update_job(variables)
-                self.log(LogLevel.ERROR, e)
+                error_info = f"{str(e)}\nstack trace:\n{traceback.format_exc()}" if self.loggingStyle != LogStyle.JSON else ""
+                error = {
+                    "message": str(e),
+                    "stack": traceback.format_exc()
+                }
+                log_from_job(LogLevel.ERROR, f"Error parsing input from job {job['id']}.\n{error_info}", extra={
+                    "error": error
+                })
                 return
         else:
             kwargs = job_dict
@@ -614,8 +635,6 @@ class ValiotWorker():
                 'context': json.dumps(context)
             })
 
-        log_from_job = self.getProcessLoggerFunction(
-            queue=job['queue'], job=job)
         src_status_conn, dst_status_conn = Pipe()
 
         def get_job_status():
@@ -655,14 +674,25 @@ class ValiotWorker():
                 try:
                     output = job_fn(**kwargs)
                 except TypeError as e:
-                    self.log(
-                        LogLevel.ERROR, f'Error starting job from queue {kwargs["queue"]["name"]}:\n{str(e)}')
-                    self.log(
-                        LogLevel.ERROR, f'Did you forget to ignore additional params in the job definition?:')
-                    self.log(LogLevel.ERROR, f'@vw.job(...)')
-                    self.log(
-                        LogLevel.ERROR, f'def my_job(my_param, my_param2, **_) # <== can be **kwargs or **_')
-                    self.log(LogLevel.ERROR, f'\t...')
+                    error_info = f"{str(e)}\nstack trace:\n{traceback.format_exc()}" if self.loggingStyle != LogStyle.JSON else ""
+                    error = {
+                        "message": str(e),
+                        "stack": traceback.format_exc()
+                    }
+                    errors.append(error)
+                    full_error_message = f'Error starting job from queue {kwargs["queue"]["name"]}:\n{str(e)}\n' + f'Did you forget to ignore additional params in the job definition?:\n' + \
+                        f'@vw.job(...)\n' + \
+                        f'def my_job(my_param, my_param2, **_) # <== can be **kwargs or **_\n' + f'\t...'
+                    if self.loggingStyle == LogStyle.JSON:
+                        log_from_job(LogLevel.ERROR, full_error_message, extra={
+                            "error": error
+                        })
+                    else:
+                        # log line by line to avoid breaking the CLI format
+                        for line in full_error_message.splitlines():
+                            log_from_job(LogLevel.ERROR, line)
+                        log_from_job(LogLevel.ERROR,
+                                     f'stack trace: \n{error["stack"]}')
                 except Exception as e:
                     error_info = f"{str(e)}\nstack trace:\n{traceback.format_exc()}" if self.loggingStyle != LogStyle.JSON else ""
                     error = {
@@ -670,14 +700,14 @@ class ValiotWorker():
                         "stack": traceback.format_exc()
                     }
                     errors.append(error)
-                    self.log(LogLevel.ERROR, f"job {job['id']} crashed unexpectedly.\n{error_info}", extra={
+                    log_from_job(LogLevel.ERROR, f"job {job['id']} crashed unexpectedly.\n{error_info}", extra={
                         "error": error
                     })
                 finally:
                     self.finish_job_gracefully(
                         job=job, job_kwargs=kwargs, output=output, errors=errors)
             p = self.context.Process(target=safe_fn, kwargs=(kwargs))
-            self.log(LogLevel.INFO, f'started job with ID {job["id"]}')
+            log_from_job(LogLevel.INFO, f'started job with ID {job["id"]}')
             p.start()
             self.runningJobs[job['id']] = {
                 'process': p,
@@ -692,7 +722,8 @@ class ValiotWorker():
                     'lock': lock
                 })
         else:
-            self.log(LogLevel.ERROR, f'Error starting job (queue={fn_name})')
+            log_from_job(LogLevel.ERROR,
+                         f'Error starting job (queue={fn_name})')
 
     def queue_locked(self, queue_name):
         """This function checks if a queue is locked.
@@ -718,28 +749,42 @@ class ValiotWorker():
             lock (object): Lock object
             action (string): Action to do with the lock (one of 'created', 'updated', 'deleted')
         """
-        queue_index = __.find_index(self.currentQueues, lambda q: q['name'] == queue['name'])
+        queue_index = __.find_index(
+            self.currentQueues, lambda q: q['name'] == queue['name'])
         current_queue = __.get(self.currentQueues, queue_index)
         if queue_index == -1:
-            return # no op, queue not found
+            return  # no op, queue not found
+        # TODO: find related job and pass it to the logger function (if any)
+        # TODO: may be inside "self.lockedJobs" if the job is running
+        log_from_queue = self.getProcessLoggerFunction(
+            queue=current_queue,
+            # at this point for event jobs, the job is not created yet
+            job=None
+        )
         if action == 'created':
-            self.log(LogLevel.INFO, f'Queue {queue["name"]} locked')
+            log_from_queue(LogLevel.SUCCESS, f'Queue {queue["name"]} locked')
             self.currentQueues[queue_index]['locks'] = [lock]
         elif action == 'updated':
-            self.log(LogLevel.INFO, f'Queue {queue["name"]} lock updated')
-            lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
+            log_from_queue(LogLevel.SUCCESS,
+                           f'Queue {queue["name"]} lock updated')
+            lock_index = __.find_index(
+                current_queue['locks'], lambda l: l['id'] == lock['id'])
             if lock_index == -1:
                 self.currentQueues[queue_index]['locks'].append(lock)
-                self.currentQueues[queue_index]['locks'] = __.sort_by(self.currentQueues[queue_index]['locks'], 'updatedAt', reverse=True)
+                self.currentQueues[queue_index]['locks'] = __.sort_by(
+                    self.currentQueues[queue_index]['locks'], 'updatedAt', reverse=True)
             else:
                 self.currentQueues[queue_index]['locks'][lock_index] = lock
         elif action == 'deleted':
-            self.log(LogLevel.INFO, f'Queue {queue["name"]} lock released')
-            lock_index = __.find_index(current_queue['locks'], lambda l: l['id'] == lock['id'])
+            log_from_queue(LogLevel.SUCCESS,
+                           f'Queue {queue["name"]} lock released')
+            lock_index = __.find_index(
+                current_queue['locks'], lambda l: l['id'] == lock['id'])
             if lock_index != -1:
                 self.currentQueues[queue_index]['locks'].pop(lock_index)
         else:
-            self.log(LogLevel.INFO, f'Queue {queue["name"]} unknown lock action: {action}')
+            log_from_queue(LogLevel.SUCCESS,
+                           f'Queue {queue["name"]} unknown lock action: {action}')
 
     def workerQueueEnabled(self, queue):
         """This function checks if the queue is enable.
@@ -782,17 +827,19 @@ class ValiotWorker():
         if jobs is not None and len(jobs) > 0:
             self.log(LogLevel.WARNING, f"Found {len(jobs)} jobs")
             for job in jobs:
+                log_from_job = self.getProcessLoggerFunction(
+                    queue=job['queue'], job=job)
                 if self.queue_locked(job['queue']['name']):
-                    self.log(LogLevel.ERROR,
-                             f"{job['queue']['name']} is LOCKED, job aborted")
+                    log_from_job(LogLevel.ERROR,
+                                 f"{job['queue']['name']} is LOCKED, job aborted")
                     self.abortJob(job)
                 elif self.workerQueueEnabled(job['queue']):
                     self.runJob(job)
                 else:
-                    self.log(LogLevel.WARNING,
-                             f"{job['queue']['name']} is DISABLED, skipping job")
+                    log_from_job(LogLevel.WARNING,
+                                 f"{job['queue']['name']} is DISABLED, skipping job")
         else:
-            pass # nothing to do (no jobs), left here just to be explicit
+            pass  # nothing to do (no jobs), left here just to be explicit
 
     def abortStaleJobs(self):
         """This function aborts all stale jobs.
@@ -921,22 +968,26 @@ class ValiotWorker():
             self.runningJobs.pop(f, None)  # remove any finished jobs
 
     def finish_job_gracefully(self, job, job_kwargs, output, errors=[]):
+        """This function finishes a job gracefully, updating the job status and output."""
+        # get logger function to log as if it was inside the job
+        log_from_job = self.getProcessLoggerFunction(
+            queue=job['queue'], job=job)
         if len(errors) > 0:
-            self.log(LogLevel.ERROR,
-                     f"terminating job with ID {job['id']} with errors...")
+            log_from_job(LogLevel.ERROR,
+                         f"terminating job with ID {job['id']} with errors...")
             return uploaders.update_job({
                 'id': job['id'],
                 'status': JobStatus.ERROR.value,
                 'output': json.dumps({'data': output, 'errors': errors})
             })
         elif output is None:
-            self.log(LogLevel.INFO,
-                     f"finished job with ID {job['id']} with implicit exit")
+            log_from_job(LogLevel.INFO,
+                         f"finished job with ID {job['id']} with implicit exit")
         elif type(output) == str:
-            self.log(
+            log_from_job(
                 LogLevel.INFO, f"finished job with ID {job['id']} with message: \n{output}")
         elif type(output) == dict:
-            self.log(
+            log_from_job(
                 LogLevel.INFO, f"finished job with ID {job['id']} with data: \n{output}")
 
         # if the job did call "update_job", we gotta make sure we don't override the last info sent explicitly:
@@ -948,8 +999,8 @@ class ValiotWorker():
                 last_status = JobStatus(maybe_status)
                 if (last_status in [JobStatus.FINISHED, JobStatus.ERROR, JobStatus.ABORTED, JobStatus.PAUSED]):
                     # job had already been finished explicitly
-                    self.log(LogLevel.INFO,
-                             f"job {job['id']} terminated itself correctly")
+                    log_from_job(LogLevel.INFO,
+                                 f"job {job['id']} terminated itself correctly")
                     return
                 # if it was been called, but had a status of "RUNNING", it still requires an implicit termination:
         return uploaders.update_job({
@@ -966,9 +1017,14 @@ class ValiotWorker():
             force (bool, optional): Option to force the unlock update. Defaults to False.
         """
         unlocked = []
-        _log = log if force else self.log
         for i, job_lock in enumerate(self.lockedJobs):
             if not job_lock['process'].is_alive() or force:
+                log_from_job = self.getProcessLoggerFunction(
+                    queue=job_lock['job']['queue'],
+                    # at this point for event jobs, the job is not created yet
+                    job=job_lock['job']
+                )
+                _log = log if force else log_from_job
                 if self.unlockQueue(job_lock['job']['queue']['name'], job_lock['lock']):
                     _log(LogLevel.SUCCESS,
                          f'{job_lock["job"]["queue"]["name"]} UNLOCKED')
@@ -976,7 +1032,8 @@ class ValiotWorker():
                 else:
                     _log(LogLevel.ERROR,
                          f'error unlocking {job_lock["job"]["queue"]["name"]}')
-                    unlocked.append(i) # remove from lockedJobs anyways to avoid infinite prints
+                    # remove from lockedJobs anyways to avoid infinite prints
+                    unlocked.append(i)
         if unlocked:
             unlocked.reverse()
             for u in unlocked:
@@ -991,8 +1048,22 @@ class ValiotWorker():
                 continue  # nothing to run
             elapsed = current_time - queue['start_time']
             if elapsed >= queue['config']['timeout']:
-                self.log(LogLevel.WARNING,
-                         f'Event {queue["name"]} timed out, running...')
+                eventQueue = __.find(
+                    self.currentQueues,
+                    lambda cq: queue.get(
+                        'name') and queue['name'] == cq['name']
+                )
+                if not eventQueue:
+                    self.log(
+                        LogLevel.WARNING, f'EVENT { queue["name"] } TRIGGERED BUT NOT FOUND, SKIPPING...')
+                    return  # Skipping event due to missing queue
+                log_from_job = self.getProcessLoggerFunction(
+                    queue=eventQueue,
+                    # at this point for event jobs, the job is not created yet
+                    job=None
+                )
+                log_from_job(LogLevel.WARNING,
+                             f'Event {queue["name"]} timed out, running...')
                 self.runEvent(queue['name'])
 
     def runFrequencyQueues(self):
@@ -1030,7 +1101,7 @@ class ValiotWorker():
                 if self.workerQueueEnabled(queue):
                     if self.queue_locked(queue["name"]):
                         self.log(LogLevel.DEBUG,
-                                    f"{queue['name']} is LOCKED, postponing...")
+                                 f"{queue['name']} is LOCKED, postponing...")
                     else:
                         self.gql.mutate(
                             mutation=mutations.create_job,
@@ -1070,8 +1141,10 @@ class ValiotWorker():
             if not job:
                 return  # Possibly a job for another worker
             if self.queue_locked(job['queue']['name']):
-                self.log(LogLevel.ERROR,
-                         f"{job['queue']['name']} is LOCKED, job aborted")
+                log_from_job = self.getProcessLoggerFunction(
+                    queue=job['queue'], job=job)
+                log_from_job(LogLevel.ERROR,
+                             f"{job['queue']['name']} is LOCKED, job aborted")
                 self.abortJob(job)
             elif self.workerQueueEnabled(job['queue']):
                 self.runJob(job)
@@ -1114,12 +1187,18 @@ class ValiotWorker():
         """
         queuesByName = __.group_by(self.currentQueues, 'name')
         currentQueue = __.get(queuesByName, f'{queue_name}.0')
+        log_from_job = self.getProcessLoggerFunction(
+            queue=currentQueue,
+            # at this point for event jobs, the job is not created yet
+            job=None
+        )
+
         if self.queue_locked(currentQueue['name']):
-            self.log(LogLevel.WARNING,
-                     f"{currentQueue['name']} is LOCKED, event postponed")
+            log_from_job(LogLevel.WARNING,
+                         f"{currentQueue['name']} is LOCKED, event postponed")
             return False
         elif not self.workerQueueEnabled(currentQueue):
-            self.log(
+            log_from_job(
                 LogLevel.WARNING, f'Event triggered for {queue_name} but Queue not enabled, skipping...')
             return True
         data = self.eventQueues[queue_name]["mailbox"]
@@ -1138,10 +1217,14 @@ class ValiotWorker():
             }
         )
         if errors:
-            self.log(LogLevel.ERROR, f'Error starting event:\n{errors}')
+            log_from_job(LogLevel.ERROR, f'Error starting event:\n{errors}')
             return True
         job = __.get(response, 'job.result')
 
+        # now that we have a job id, we can log properly
+        log_from_job = self.getProcessLoggerFunction(
+            queue=currentQueue, job=job)
+
         @trackcalls
         def update_this_job(variables):
             # * funcion de utilidad para actualizar job sin necesidad de conocer su ID
@@ -1177,7 +1260,7 @@ class ValiotWorker():
             'context': __.get(currentQueue, 'context', dict()),
             'update_context': update_this_context,
             'data': data,
-            'log': self.getProcessLoggerFunction(queue=currentQueue, job=job)
+            'log': log_from_job
         }
         kwargs['kwargs'] = {**kwargs}
 
@@ -1187,14 +1270,25 @@ class ValiotWorker():
             try:
                 output = self.eventQueues[queue_name]['function'](**kwargs)
             except TypeError as e:
-                self.log(
-                    LogLevel.ERROR, f'Error starting job from queue {queue_name}:\n{str(e)}')
-                self.log(
-                    LogLevel.ERROR, f'Did you forget to ignore additional params in the job definition?:')
-                self.log(LogLevel.ERROR, f'@vw.job(...)')
-                self.log(
-                    LogLevel.ERROR, f'def my_job(my_param, my_param2, **_) # <== can be **kwargs or **_')
-                self.log(LogLevel.ERROR, f'\t...')
+                error_info = f"{str(e)}\nstack trace:\n{traceback.format_exc()}" if self.loggingStyle != LogStyle.JSON else ""
+                error = {
+                    "message": str(e),
+                    "stack": traceback.format_exc()
+                }
+                errors.append(error)
+                full_error_message = f'Error starting job from queue {kwargs["queue"]["name"]}:\n{str(e)}\n' + f'Did you forget to ignore additional params in the job definition?:\n' + \
+                    f'@vw.job(...)\n' + \
+                    f'def my_job(my_param, my_param2, **_) # <== can be **kwargs or **_\n' + f'\t...'
+                if self.loggingStyle == LogStyle.JSON:
+                    log_from_job(LogLevel.ERROR, full_error_message, extra={
+                        "error": error
+                    })
+                else:
+                    # log line by line to avoid breaking the CLI format
+                    for line in full_error_message.splitlines():
+                        log_from_job(LogLevel.ERROR, line)
+                    log_from_job(LogLevel.ERROR,
+                                 f'stack trace: \n{error["stack"]}')
             except Exception as e:
                 error_info = f"{str(e)}\nstack trace:\n{traceback.format_exc()}" if self.loggingStyle != LogStyle.JSON else ""
                 error = {
@@ -1202,7 +1296,7 @@ class ValiotWorker():
                     "stack": traceback.format_exc()
                 }
                 errors.append(error)
-                self.log(LogLevel.ERROR, f"job {job['id']} crashed unexpectedly.\n{error_info}", extra={
+                log_from_job(LogLevel.ERROR, f"job {job['id']} crashed unexpectedly.\n{error_info}", extra={
                     "error": error
                 })
             finally:
@@ -1243,7 +1337,21 @@ class ValiotWorker():
             if not self.workerQueueEnabled(queue):
                 return  # Skipping event
             if len(self.eventQueues[queue["name"]]["mailbox"]) == 0:
-                self.log(
+                eventQueue = __.find(
+                    self.currentQueues,
+                    lambda cq: queue.get(
+                        'name') and queue['name'] == cq['name']
+                )
+                if not eventQueue:
+                    self.log(
+                        LogLevel.WARNING, f'EVENT { queue["name"] } TRIGGERED BUT NOT FOUND, SKIPPING...')
+                    return  # Skipping event due to missing queue
+                log_from_job = self.getProcessLoggerFunction(
+                    queue=eventQueue,
+                    # at this point for event jobs, the job is not created yet
+                    job=None
+                )
+                log_from_job(
                     LogLevel.WARNING, f'EVENT { queue["name"] } TRIGGERED, BUILDING BATCH')
                 self.eventQueues[queue["name"]]["start_time"] = time.time()
             self.eventQueues[queue["name"]]["mailbox"].append(data)
@@ -1358,7 +1466,9 @@ class ValiotWorker():
         """
         job_zero_padding = len(str(__.get(self.worker, 'jobs.0.id')))
         log_queue_key = __.get(queue, 'name', 'main')
-        log_queue = self.logQueues[log_queue_key]
+        # log to the main queue if the queue is not defined (may exist in another universe)
+        log_queue = __.get(self.logQueues, log_queue_key,
+                           self.logQueues['main'])
         # to log this in a single line, we prefer to keep it small
         W = str(self.worker["id"]).zfill(2)
         Q = str(__.get(queue, 'id', 0)).zfill(3)
@@ -1468,7 +1578,7 @@ class ValiotWorker():
             if self.pollingMode == PollingMode.QUERY:
                 self.processJobs()
             else:
-                pass # subscription doesn't need to process jobs manually, but be explicit about it
+                pass  # subscription doesn't need to process jobs manually, but be explicit about it
             if self.useRedis:
                 self.redis.monitorRedisSubscriptions()
             self.monitorContinuousJobs()
@@ -1494,7 +1604,8 @@ class ValiotWorker():
         """This function starts the health check.
         """
         # making the thread daemon allows the main thread to exit even if the health check thread is still running
-        self.healthCheckThread = Thread(target=health_check_probe, daemon=True, name='health_check_probe', args=(self.log, self.loggingStyle))
+        self.healthCheckThread = Thread(
+            target=health_check_probe, daemon=True, name='health_check_probe', args=(self.log, self.loggingStyle))
         self.healthCheckThread.start()
         self.log(LogLevel.SUCCESS, 'Health check started')
 
@@ -1503,12 +1614,14 @@ class ValiotWorker():
         """
         current_env = os.environ.get('ENV')
         if current_env == 'dev':
-            self.log(LogLevel.WARNING, 'Skipping worker readiness check in dev environment')
+            self.log(LogLevel.WARNING,
+                     'Skipping worker readiness check in dev environment')
             return
         initial_delay = os.environ.get('INITIAL_DELAY', 60)
         termination_period = os.environ.get('TERMINATION_PERIOD', 10)
         total_delay = int(initial_delay) + int(termination_period)
-        self.log(LogLevel.INFO, f'Waiting {total_delay} seconds before starting worker...')
+        self.log(LogLevel.INFO,
+                 f'Waiting {total_delay} seconds before starting worker...')
         time.sleep(int(total_delay))
 
     def run(self, interval=1.0):
